Index: /trunk/grails-app/services/PersonService.groovy
===================================================================
--- /trunk/grails-app/services/PersonService.groovy	(revision 197)
+++ /trunk/grails-app/services/PersonService.groovy	(revision 198)
@@ -1,3 +1,4 @@
-/* Provides a service class with some methods that integrate the Person domain class and Acegi security.
+/**
+ * Provides a service class with some methods that integrate the Person domain class and Acegi security.
  *
  */
@@ -8,5 +9,8 @@
     def authenticateService
 
     // Get current user as a Person and in a safe way to avoid a null userDomain during bootstrap.
     def currentUser() {
         if(authenticateService.userDomain()) {
@@ -14,10 +18,14 @@
         }
         else {
-            //println "Warning: userDomain not active yet, attempting to return Person #1"
+            log.warn "userDomain not active, attempting to return Person #1."
             return Person.get(1)
         }
     }
 
-    // Convenience wrapper.
+    /**
+    * Convenience wrapper around authenticateService.encodePassword().
+    * @param passClearText The clear text password to encode.
+    * @returns The encoded password.
+    */
     def encodePassword(passClearText) {
         authenticateService.encodePassword(passClearText)
@@ -8,5 +9,8 @@
     def authenticateService
 
-    // Get current user as a Person and in a safe way to avoid a null userDomain during bootstrap.
+    /**
+    * Get the current user in a safe way to avoid a null userDomain.
+    * @returns The current user or the 'system' person (Person #1) if userDomain() is not active.
+    */
     def currentUser() {
         if(authenticateService.userDomain()) {
